<?php

namespace Litepie\SubscribeContent\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Litepie\SubscribeContent\Http\Requests\SubscribeContentRequest;
use Litepie\SubscribeContent\Interfaces\SubscribeContentRepositoryInterface;
use Litepie\SubscribeContent\Models\SubscribeContent;
use Litepie\SubscribeContent\Forms\SubscribeContent as Form;

/**
 * APIController  class for subscribe_content.
 */
class SubscribeContentAPIController extends BaseController
{

    /**
     * Initialize subscribe_content resource controller.
     *
     * @param type SubscribeContentRepositoryInterface $subscribe_content
     *
     * @return null
     */
    public function __construct(SubscribeContentRepositoryInterface $subscribe_content)
    {
        parent::__construct();
        $this->repository = $subscribe_content;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litepie\SubscribeContent\Repositories\Criteria\SubscribeContentResourceCriteria::class);
    }

    /**
     * Display a list of subscribe_content.
     *
     * @return Response
     */
    public function index(SubscribeContentRequest $request)
    {
        return $this->repository
            ->setPresenter(\Litepie\SubscribeContent\Repositories\Presenter\SubscribeContentPresenter::class)
            ->paginate();
    }

    /**
     * Display subscribe_content.
     *
     * @param Request $request
     * @param Model   $subscribe_content
     *
     * @return Response
     */
    public function show(SubscribeContentRequest $request, SubscribeContent $subscribe_content)
    {
        return $subscribe_content->setPresenter(\Litepie\SubscribeContent\Repositories\Presenter\SubscribeContentListPresenter::class);
        ;
    }

    /**
     * Create new subscribe_content.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(SubscribeContentRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('subscribe_content::subscribe_content.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('subscribe_content/subscribe_content/' . $subscribe_content->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('subscribe_content/subscribe_content');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the subscribe_content.
     *
     * @param Request $request
     * @param Model   $subscribe_content
     *
     * @return Response
     */
    public function update(SubscribeContentRequest $request, SubscribeContent $subscribe_content)
    {
        try {
            $data = $request->all();

            $subscribe_content->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('subscribe_content::subscribe_content.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('subscribe_content/subscribe_content/' . $subscribe_content->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('subscribe_content/subscribe_content/' . $subscribe_content->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the subscribe_content.
     *
     * @param Model   $subscribe_content
     *
     * @return Response
     */
    public function destroy(SubscribeContentRequest $request, SubscribeContent $subscribe_content)
    {
        try {
            $subscribe_content->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('subscribe_content::subscribe_content.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('subscribe_content/subscribe_content/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('subscribe_content/subscribe_content/' . $subscribe_content->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
