<?php

namespace Litepie\SubscribeContent\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litepie\SubscribeContent\Http\Requests\SubscribeContentRequest;
use Litepie\SubscribeContent\Interfaces\SubscribeContentRepositoryInterface;
use Litepie\SubscribeContent\Models\SubscribeContent;

/**
 * Resource controller class for subscribe_content.
 */
class SubscribeContentResourceController extends BaseController
{

    /**
     * Initialize subscribe_content resource controller.
     *
     * @param type SubscribeContentRepositoryInterface $subscribe_content
     *
     * @return null
     */
    public function __construct(SubscribeContentRepositoryInterface $subscribe_content)
    {
        parent::__construct();
        $this->repository = $subscribe_content;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litepie\SubscribeContent\Repositories\Criteria\SubscribeContentResourceCriteria::class);
    }

    /**
     * Display a list of subscribe_content.
     *
     * @return Response
     */
    public function index(SubscribeContentRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litepie\SubscribeContent\Repositories\Presenter\SubscribeContentPresenter::class)
                ->$function();
        }

        $subscribe_contents = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('subscribe_content::subscribe_content.names'))
            ->view('subscribe_content::subscribe_content.index', true)
            ->data(compact('subscribe_contents', 'view'))
            ->output();
    }

    /**
     * Display subscribe_content.
     *
     * @param Request $request
     * @param Model   $subscribe_content
     *
     * @return Response
     */
    public function show(SubscribeContentRequest $request, SubscribeContent $subscribe_content)
    {

        if ($subscribe_content->exists) {
            $view = 'subscribe_content::subscribe_content.show';
        } else {
            $view = 'subscribe_content::subscribe_content.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('subscribe_content::subscribe_content.name'))
            ->data(compact('subscribe_content'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new subscribe_content.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(SubscribeContentRequest $request)
    {

        $subscribe_content = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('subscribe_content::subscribe_content.name')) 
            ->view('subscribe_content::subscribe_content.create', true) 
            ->data(compact('subscribe_content'))
            ->output();
    }

    /**
     * Create new subscribe_content.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(SubscribeContentRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $subscribe_content                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('subscribe_content::subscribe_content.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('subscribe_content/subscribe_content/' . $subscribe_content->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/subscribe_content/subscribe_content'))
                ->redirect();
        }

    }

    /**
     * Show subscribe_content for editing.
     *
     * @param Request $request
     * @param Model   $subscribe_content
     *
     * @return Response
     */
    public function edit(SubscribeContentRequest $request, SubscribeContent $subscribe_content)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('subscribe_content::subscribe_content.name'))
            ->view('subscribe_content::subscribe_content.edit', true)
            ->data(compact('subscribe_content'))
            ->output();
    }

    /**
     * Update the subscribe_content.
     *
     * @param Request $request
     * @param Model   $subscribe_content
     *
     * @return Response
     */
    public function update(SubscribeContentRequest $request, SubscribeContent $subscribe_content)
    {
        try {
            $attributes = $request->all();

            $subscribe_content->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('subscribe_content::subscribe_content.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('subscribe_content/subscribe_content/' . $subscribe_content->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('subscribe_content/subscribe_content/' . $subscribe_content->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the subscribe_content.
     *
     * @param Model   $subscribe_content
     *
     * @return Response
     */
    public function destroy(SubscribeContentRequest $request, SubscribeContent $subscribe_content)
    {
        try {

            $subscribe_content->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('subscribe_content::subscribe_content.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('subscribe_content/subscribe_content/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('subscribe_content/subscribe_content/' . $subscribe_content->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple subscribe_content.
     *
     * @param Model   $subscribe_content
     *
     * @return Response
     */
    public function delete(SubscribeContentRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('subscribe_content::subscribe_content.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('subscribe_content/subscribe_content'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/subscribe_content/subscribe_content'))
                ->redirect();
        }

    }

    /**
     * Restore deleted subscribe_contents.
     *
     * @param Model   $subscribe_content
     *
     * @return Response
     */
    public function restore(SubscribeContentRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('subscribe_content::subscribe_content.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/subscribe_content/subscribe_content'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/subscribe_content/subscribe_content/'))
                ->redirect();
        }

    }

}
