<?php

namespace Litepie\SubscribeContent\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\SubscribeContent\Models\SubscribeContent;

class SubscribeContentPolicy
{

    /**
     * Determine if the given user can view the subscribe_content.
     *
     * @param UserPolicy $user
     * @param SubscribeContent $subscribe_content
     *
     * @return bool
     */
    public function view(UserPolicy $user, SubscribeContent $subscribe_content)
    {
        if ($user->canDo('subscribe_content.subscribe_content.view') && $user->isAdmin()) {
            return true;
        }

        return $subscribe_content->user_id == user_id() && $subscribe_content->user_type == user_type();
    }

    /**
     * Determine if the given user can create a subscribe_content.
     *
     * @param UserPolicy $user
     * @param SubscribeContent $subscribe_content
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('subscribe_content.subscribe_content.create');
    }

    /**
     * Determine if the given user can update the given subscribe_content.
     *
     * @param UserPolicy $user
     * @param SubscribeContent $subscribe_content
     *
     * @return bool
     */
    public function update(UserPolicy $user, SubscribeContent $subscribe_content)
    {
        if ($user->canDo('subscribe_content.subscribe_content.edit') && $user->isAdmin()) {
            return true;
        }

        return $subscribe_content->user_id == user_id() && $subscribe_content->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given subscribe_content.
     *
     * @param UserPolicy $user
     * @param SubscribeContent $subscribe_content
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, SubscribeContent $subscribe_content)
    {
        return $subscribe_content->user_id == user_id() && $subscribe_content->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given subscribe_content.
     *
     * @param UserPolicy $user
     * @param SubscribeContent $subscribe_content
     *
     * @return bool
     */
    public function verify(UserPolicy $user, SubscribeContent $subscribe_content)
    {
        if ($user->canDo('subscribe_content.subscribe_content.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given subscribe_content.
     *
     * @param UserPolicy $user
     * @param SubscribeContent $subscribe_content
     *
     * @return bool
     */
    public function approve(UserPolicy $user, SubscribeContent $subscribe_content)
    {
        if ($user->canDo('subscribe_content.subscribe_content.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
